@@ -224,8 +224,18 @@ public class CheckstyleAntTask extends Task {
     /**
      * Sets URL to the configuration.
      * @param url the URL of the configuration to use
+     * @deprecated please use setConfigUrl instead
      */
+    @Deprecated
     public void setConfigURL(URL url) {
+        setConfigUrl(url);
+    }
+
+    /**
+     * Sets URL to the configuration.
+     * @param url the URL of the configuration to use
+     */
+    public void setConfigUrl(URL url) {
         setConfigLocation(url.toExternalForm());
     }
 
@@ -574,7 +584,7 @@ public class CheckstyleAntTask extends Task {
         public AuditListener createListener(Task task) throws IOException {
             if (formatterType != null
                     && E_XML.equals(formatterType.getValue())) {
-                return createXMLLogger(task);
+                return createXmlLogger(task);
             }
             return createDefaultLogger(task);
         }
@@ -602,7 +612,7 @@ public class CheckstyleAntTask extends Task {
          * @return an XMLLogger instance
          * @throws IOException if an error occurs
          */
-        private AuditListener createXMLLogger(Task task) throws IOException {
+        private AuditListener createXmlLogger(Task task) throws IOException {
             if (toFile == null || !useFile) {
                 return new XMLLogger(new LogOutputStream(task,
                         Project.MSG_INFO), true);
