@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2014  Oliver Burn
+// Copyright (C) 2001-2015 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -16,19 +16,18 @@
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ////////////////////////////////////////////////////////////////////////////////
+
 package com.puppycrawl.tools.checkstyle.api;
 
 /**
  * An interface for filtering AuditEvents.
  * @author Rick Giles
  */
-public interface Filter
-
-{
+public interface Filter {
     /**
      * Determines whether or not a filtered AuditEvent is accepted.
-     * @param aEvent the AudtiEvent to filter.
-     * @return true if the aEvent is accepted.
+     * @param event the AuditEvent to filter.
+     * @return true if the event is accepted.
      */
-    boolean accept(AuditEvent aEvent);
+    boolean accept(AuditEvent event);
 }
