@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2014  Oliver Burn
+// Copyright (C) 2001-2015 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -16,17 +16,19 @@
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ////////////////////////////////////////////////////////////////////////////////
+
 package com.puppycrawl.tools.checkstyle.checks.whitespace;
 
+import org.apache.commons.lang3.ArrayUtils;
+
 import com.puppycrawl.tools.checkstyle.api.Check;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 
 /**
- * <p>
  * Checks that a token is surrounded by whitespace.
  *
- * <p> By default the check will check the following operators:
+ * <p>By default the check will check the following operators:
  *  {@link TokenTypes#LITERAL_ASSERT ASSERT},
  *  {@link TokenTypes#ASSIGN ASSIGN},
  *  {@link TokenTypes#BAND BAND},
@@ -79,14 +81,13 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *  {@link TokenTypes#LITERAL_ASSERT LITERAL_ASSERT},
  *  {@link TokenTypes#TYPE_EXTENSION_AND TYPE_EXTENSION_AND}.
  *
- * <p>
- * An example of how to configure the check is:
+ * <p>An example of how to configure the check is:
  *
  * <pre>
  * &lt;module name="WhitespaceAround"/&gt;
  * </pre>
  *
- * <p> An example of how to configure the check for whitespace only around
+ * <p>An example of how to configure the check for whitespace only around
  * assignment operators is:
  *
  * <pre>
@@ -96,13 +97,11 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * &lt;/module&gt;
  * </pre>
  *
- * <p>
- * In addition, this check can be configured to allow empty methods, types,
+ * <p>In addition, this check can be configured to allow empty methods, types,
  * for, while, do-while loops and constructor bodies.
  * For example:
  *
- * <p>
- * <pre><code>
+ * <pre>{@code
  * public MyClass() {}      // empty constructor
  * public void func() {}    // empty method
  * public interface Foo {} // empty interface
@@ -113,64 +112,62 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * for (int i = 1; i &gt; 1; i++) {} // empty for loop
  * do {} while (i = 1); // empty do-while loop
  * public @interface Beta {} // empty annotation type
- * </code></pre>
+ * }</pre>
  *
- * <p>
- * To configure the check to allow empty method blocks use
+ * <p>To configure the check to allow empty method blocks use
  *
- * <p>
  * <pre>   &lt;property name="allowEmptyMethods" value="true" /&gt;</pre>
  *
- * <p>
- * To configure the check to allow empty constructor blocks use
+ * <p>To configure the check to allow empty constructor blocks use
  *
- * <p>
  * <pre>   &lt;property name="allowEmptyConstructors" value="true" /&gt;</pre>
  *
- * <p>
- * To configure the check to allow empty type blocks use
+ * <p>To configure the check to allow empty type blocks use
  *
- * <p>
  * <pre>   &lt;property name="allowEmptyTypes" value="true" /&gt;</pre>
  *
- * <p>
- * To configure the check to allow empty loop blocks use
+ * <p>To configure the check to allow empty loop blocks use
  *
- * <p>
  * <pre>   &lt;property name="allowEmptyLoops" value="true" /&gt;</pre>
  *
- *
- * <p>
- * Also, this check can be configured to ignore the colon in an enhanced for
+ * <p>Also, this check can be configured to ignore the colon in an enhanced for
  * loop. The colon in an enhanced for loop is ignored by default
  *
- * <p>
- * To configure the check to ignore the colon
+ * <p>To configure the check to ignore the colon
  *
- * <p>
  * <pre>   &lt;property name="ignoreEnhancedForColon" value="true" /&gt;</pre>
  *
- *
  * @author Oliver Burn
  * @author maxvetrenko
- * @version 1.0
+ * @author Andrei Selkin
  */
-public class WhitespaceAroundCheck extends Check
-{
+public class WhitespaceAroundCheck extends Check {
+
+    /**
+     * A key is pointing to the warning message text in "messages.properties"
+     * file.
+     */
+    public static final String WS_NOT_PRECEDED = "ws.notPreceded";
+
+    /**
+     * A key is pointing to the warning message text in "messages.properties"
+     * file.
+     */
+    public static final String WS_NOT_FOLLOWED = "ws.notFollowed";
+
     /** Whether or not empty constructor bodies are allowed. */
-    private boolean mAllowEmptyCtors;
+    private boolean allowEmptyConstructors;
     /** Whether or not empty method bodies are allowed. */
-    private boolean mAllowEmptyMethods;
-    /** Whether or not empty classes, enums and interfaces are allowed*/
-    private boolean mAllowEmptyTypes;
-    /** Whether or not empty loops are allowed*/
-    private boolean mAllowEmptyLoops;
-    /** whether or not to ignore a colon in a enhanced for loop */
-    private boolean mIgnoreEnhancedForColon = true;
+    private boolean allowEmptyMethods;
+    /** Whether or not empty classes, enums and interfaces are allowed. */
+    private boolean allowEmptyTypes;
+    /** Whether or not empty loops are allowed. */
+    private boolean allowEmptyLoops;
+    /** Whether or not to ignore a colon in a enhanced for loop. */
+    private boolean ignoreEnhancedForColon = true;
 
     @Override
-    public int[] getDefaultTokens()
-    {
+    public int[] getDefaultTokens() {
         return new int[] {
             TokenTypes.ASSIGN,
             TokenTypes.BAND,
@@ -225,116 +222,125 @@ public class WhitespaceAroundCheck extends Check
         };
     }
 
+    @Override
+    public int[] getAcceptableTokens() {
+        return new int[] {
+            TokenTypes.ASSIGN,
+            TokenTypes.BAND,
+            TokenTypes.BAND_ASSIGN,
+            TokenTypes.BOR,
+            TokenTypes.BOR_ASSIGN,
+            TokenTypes.BSR,
+            TokenTypes.BSR_ASSIGN,
+            TokenTypes.BXOR,
+            TokenTypes.BXOR_ASSIGN,
+            TokenTypes.COLON,
+            TokenTypes.DIV,
+            TokenTypes.DIV_ASSIGN,
+            TokenTypes.DO_WHILE,
+            TokenTypes.EQUAL,
+            TokenTypes.GE,
+            TokenTypes.GT,
+            TokenTypes.LAND,
+            TokenTypes.LCURLY,
+            TokenTypes.LE,
+            TokenTypes.LITERAL_CATCH,
+            TokenTypes.LITERAL_DO,
+            TokenTypes.LITERAL_ELSE,
+            TokenTypes.LITERAL_FINALLY,
+            TokenTypes.LITERAL_FOR,
+            TokenTypes.LITERAL_IF,
+            TokenTypes.LITERAL_RETURN,
+            TokenTypes.LITERAL_SWITCH,
+            TokenTypes.LITERAL_SYNCHRONIZED,
+            TokenTypes.LITERAL_TRY,
+            TokenTypes.LITERAL_WHILE,
+            TokenTypes.LOR,
+            TokenTypes.LT,
+            TokenTypes.MINUS,
+            TokenTypes.MINUS_ASSIGN,
+            TokenTypes.MOD,
+            TokenTypes.MOD_ASSIGN,
+            TokenTypes.NOT_EQUAL,
+            TokenTypes.PLUS,
+            TokenTypes.PLUS_ASSIGN,
+            TokenTypes.QUESTION,
+            TokenTypes.RCURLY,
+            TokenTypes.SL,
+            TokenTypes.SLIST,
+            TokenTypes.SL_ASSIGN,
+            TokenTypes.SR,
+            TokenTypes.SR_ASSIGN,
+            TokenTypes.STAR,
+            TokenTypes.STAR_ASSIGN,
+            TokenTypes.LITERAL_ASSERT,
+            TokenTypes.TYPE_EXTENSION_AND,
+            TokenTypes.WILDCARD_TYPE,
+            TokenTypes.GENERIC_START,
+            TokenTypes.GENERIC_END,
+        };
+    }
+
+    @Override
+    public int[] getRequiredTokens() {
+        return ArrayUtils.EMPTY_INT_ARRAY;
+    }
+
     /**
      * Sets whether or not empty method bodies are allowed.
-     * @param aAllow <code>true</code> to allow empty method bodies.
+     * @param allow {@code true} to allow empty method bodies.
      */
-    public void setAllowEmptyMethods(boolean aAllow)
-    {
-        mAllowEmptyMethods = aAllow;
+    public void setAllowEmptyMethods(boolean allow) {
+        allowEmptyMethods = allow;
     }
 
     /**
      * Sets whether or not empty constructor bodies are allowed.
-     * @param aAllow <code>true</code> to allow empty constructor bodies.
+     * @param allow {@code true} to allow empty constructor bodies.
      */
-    public void setAllowEmptyConstructors(boolean aAllow)
-    {
-        mAllowEmptyCtors = aAllow;
+    public void setAllowEmptyConstructors(boolean allow) {
+        allowEmptyConstructors = allow;
     }
 
     /**
      * Sets whether or not to ignore the whitespace around the
      * colon in an enhanced for loop.
-     * @param aIgnore <code>true</code> to ignore enhanced for colon.
+     * @param ignore {@code true} to ignore enhanced for colon.
      */
-    public void setIgnoreEnhancedForColon(boolean aIgnore)
-    {
-        mIgnoreEnhancedForColon = aIgnore;
+    public void setIgnoreEnhancedForColon(boolean ignore) {
+        ignoreEnhancedForColon = ignore;
     }
 
     /**
      * Sets whether or not empty type bodies are allowed.
-     * @param aAllow <code>true</code> to allow empty type bodies.
+     * @param allow {@code true} to allow empty type bodies.
      */
-    public void setAllowEmptyTypes(boolean aAllow)
-    {
-        mAllowEmptyTypes = aAllow;
+    public void setAllowEmptyTypes(boolean allow) {
+        allowEmptyTypes = allow;
     }
 
     /**
      * Sets whether or not empty loop bodies are allowed.
-     * @param aAllow <code>true</code> to allow empty loops bodies.
+     * @param allow {@code true} to allow empty loops bodies.
      */
-    public void setAllowEmptyLoops(boolean aAllow)
-    {
-        mAllowEmptyLoops = aAllow;
+    public void setAllowEmptyLoops(boolean allow) {
+        allowEmptyLoops = allow;
     }
 
     @Override
-    public void visitToken(DetailAST aAST)
-    {
-        final int currentType = aAST.getType();
-        final int parentType = aAST.getParent().getType();
-
-        // Check for CURLY in array initializer
-        if (((currentType == TokenTypes.RCURLY)
-                || (currentType == TokenTypes.LCURLY))
-            && ((parentType == TokenTypes.ARRAY_INIT)
-                || (parentType == TokenTypes.ANNOTATION_ARRAY_INIT)))
-        {
+    public void visitToken(DetailAST ast) {
+        final int currentType = ast.getType();
+        if (isNotRelevantSituation(ast, currentType)) {
             return;
         }
 
-        // Check for import pkg.name.*;
-        if ((currentType == TokenTypes.STAR)
-            && (parentType == TokenTypes.DOT))
-        {
-            return;
-        }
+        final String line = getLine(ast.getLineNo() - 1);
+        final int before = ast.getColumnNo() - 1;
+        final int after = ast.getColumnNo() + ast.getText().length();
 
-        // Check for an SLIST that has a parent CASE_GROUP. It is not a '{'.
-        if ((currentType == TokenTypes.SLIST)
-            && (parentType == TokenTypes.CASE_GROUP))
-        {
-            return;
-        }
-
-        if ((currentType == TokenTypes.COLON)) {
-            //we do not want to check colon for cases and defaults
-            if (parentType == TokenTypes.LITERAL_DEFAULT
-                || parentType == TokenTypes.LITERAL_CASE)
-            {
-                return;
-            }
-            else if (parentType == TokenTypes.FOR_EACH_CLAUSE
-                && this.mIgnoreEnhancedForColon)
-            {
-                return;
-            }
-        }
-
-        // Checks if empty methods, ctors or loops are allowed.
-        if (isEmptyMethodBlock(aAST, parentType)
-                || isEmptyCtorBlock(aAST, parentType)
-                || isEmptyLoop(aAST, parentType))
-        {
-            return;
-        }
-
-        // Checks if empty classes, interfaces or enums are allowed
-        if (mAllowEmptyTypes && (isEmptyType(aAST, parentType))) {
-            return;
-        }
-
-        final String[] lines = getLines();
-        final String line = lines[aAST.getLineNo() - 1];
-        final int before = aAST.getColumnNo() - 1;
-        final int after = aAST.getColumnNo() + aAST.getText().length();
-
-        if ((before >= 0) && !Character.isWhitespace(line.charAt(before))) {
-            log(aAST.getLineNo(), aAST.getColumnNo(),
-                    "ws.notPreceded", aAST.getText());
+        if (before >= 0 && !Character.isWhitespace(line.charAt(before))) {
+            log(ast.getLineNo(), ast.getColumnNo(),
+                    WS_NOT_PRECEDED, ast.getText());
         }
 
         if (after >= line.length()) {
@@ -344,124 +350,194 @@ public class WhitespaceAroundCheck extends Check
         final char nextChar = line.charAt(after);
         if (!Character.isWhitespace(nextChar)
             // Check for "return;"
-            && !((currentType == TokenTypes.LITERAL_RETURN)
-                && (aAST.getFirstChild().getType() == TokenTypes.SEMI))
-            // Check for "})" or "};" or "},". Happens with anon-inners
-            && !((currentType == TokenTypes.RCURLY)
-                && ((nextChar == ')')
-                    || (nextChar == ';')
-                    || (nextChar == ',')
-                    || (nextChar == '.'))))
-        {
-            log(aAST.getLineNo(), aAST.getColumnNo() + aAST.getText().length(),
-                    "ws.notFollowed", aAST.getText());
+            && !(currentType == TokenTypes.LITERAL_RETURN
+                && ast.getFirstChild().getType() == TokenTypes.SEMI)
+            && !isAnonymousInnerClassEnd(currentType, nextChar)) {
+
+            log(ast.getLineNo(), ast.getColumnNo() + ast.getText().length(),
+                    WS_NOT_FOLLOWED, ast.getText());
         }
     }
 
     /**
-     * Test if the given <code>DetailAST</code> is part of an allowed empty
-     * method block.
-     * @param aAST the <code>DetailAST</code> to test.
-     * @param aParentType the token type of <code>aAST</code>'s parent.
-     * @return <code>true</code> if <code>aAST</code> makes up part of an
-     *         allowed empty method block.
+     * Check for "})" or "};" or "},". Happens with anon-inners
+     * @param currentType token
+     * @param nextChar next symbol
+     * @return true is that is end of anon inner class
      */
-    private boolean isEmptyMethodBlock(DetailAST aAST, int aParentType)
-    {
-        return mAllowEmptyMethods
-            && isEmptyBlock(aAST, aParentType, TokenTypes.METHOD_DEF);
+    private static boolean isAnonymousInnerClassEnd(int currentType, char nextChar) {
+        return currentType == TokenTypes.RCURLY
+            && (nextChar == ')'
+                || nextChar == ';'
+                || nextChar == ','
+                || nextChar == '.');
     }
 
     /**
-     * Test if the given <code>DetailAST</code> is part of an allowed empty
-     * constructor (ctor) block.
-     * @param aAST the <code>DetailAST</code> to test.
-     * @param aParentType the token type of <code>aAST</code>'s parent.
-     * @return <code>true</code> if <code>aAST</code> makes up part of an
-     *         allowed empty constructor block.
+     * Is ast not a target of Check.
+     * @param ast ast
+     * @param currentType type of ast
+     * @return true is ok to skip validation
      */
-    private boolean isEmptyCtorBlock(DetailAST aAST, int aParentType)
-    {
-        return mAllowEmptyCtors
-            && isEmptyBlock(aAST, aParentType, TokenTypes.CTOR_DEF);
+    private boolean isNotRelevantSituation(DetailAST ast, int currentType) {
+        final int parentType = ast.getParent().getType();
+        final boolean starImport = currentType == TokenTypes.STAR
+                && parentType == TokenTypes.DOT;
+        final boolean slistInsideCaseGroup = currentType == TokenTypes.SLIST
+                && parentType == TokenTypes.CASE_GROUP;
+
+        final boolean starImportOrSlistInsideCaseGroup = starImport || slistInsideCaseGroup;
+        final boolean colonOfCaseOrDefaultOrForEach =
+                isColonOfCaseOrDefault(currentType, parentType)
+                || isColonOfForEach(currentType, parentType);
+        final boolean emptyBlockOrType = isEmptyBlock(ast, parentType)
+                || allowEmptyTypes && isEmptyType(ast);
+
+        return starImportOrSlistInsideCaseGroup
+                || colonOfCaseOrDefaultOrForEach
+                || emptyBlockOrType
+                || isArrayInitialization(currentType, parentType);
     }
 
     /**
-     *
-     * @param aAST aAST the <code>DetailAST</code> to test.
-     * @param aParentType the token type of <code>aAST</code>'s parent.
-     * @return <code>true</code> if <code>aAST</code> makes up part of an
-     *         allowed empty loop block.
+     * Is empty block.
+     * @param ast ast
+     * @param parentType parent
+     * @return true is block is empty
      */
-    private boolean isEmptyLoop(DetailAST aAST, int aParentType)
-    {
-        return mAllowEmptyLoops
-            && (isEmptyBlock(aAST, aParentType, TokenTypes.LITERAL_FOR)
-                    || isEmptyBlock(aAST,
-                            aParentType, TokenTypes.LITERAL_WHILE)
-                            || isEmptyBlock(aAST,
-                                    aParentType, TokenTypes.LITERAL_DO));
+    private boolean isEmptyBlock(DetailAST ast, int parentType) {
+        return isEmptyMethodBlock(ast, parentType)
+                || isEmptyCtorBlock(ast, parentType)
+                || isEmptyLoop(ast, parentType);
     }
 
     /**
-     * Test if the given <code>DetailAST</code> is part of an empty block.
-     * An example empty block might look like the following
-     * <p>
-     * <pre>   class Foo {}</pre>
-     * </p>
-     *
-     * @param aAST aAST the <code>DetailAST</code> to test.
-     * @param aParentType the token type of <code>aAST</code>'s parent.
-     * @return <code>true</code> if <code>aAST</code> makes up part of an
-     *         empty block contained under a <code>aMatch</code> token type
-     *         node.
-     */
-    private boolean isEmptyType(DetailAST aAST, int aParentType)
-    {
-        final int type = aAST.getType();
-        if ((type == TokenTypes.RCURLY || type == TokenTypes.LCURLY)
-                && aParentType == TokenTypes.OBJBLOCK)
-        {
-            final DetailAST typeNode = aAST.getParent().getParent();
-            final int matchType = typeNode.getType();
-            if (matchType == TokenTypes.CLASS_DEF
-                    || matchType == TokenTypes.INTERFACE_DEF
-                    || matchType == TokenTypes.ENUM_DEF
-                    || matchType == TokenTypes.LITERAL_NEW
-                    || matchType == TokenTypes.ANNOTATION_DEF)
-            {
-                return true;
-            }
-        }
-        return false;
-    }
-
-    /**
-     * Tests if a given <code>DetailAST</code> is part of an empty block.
+     * Tests if a given {@code DetailAST} is part of an empty block.
      * An example empty block might look like the following
      * <p>
      * <pre>   public void myMethod(int val) {}</pre>
      * </p>
      * In the above, the method body is an empty block ("{}").
      *
-     * @param aAST the <code>DetailAST</code> to test.
-     * @param aParentType the token type of <code>aAST</code>'s parent.
-     * @param aMatch the parent token type we're looking to match.
-     * @return <code>true</code> if <code>aAST</code> makes up part of an
-     *         empty block contained under a <code>aMatch</code> token type
+     * @param ast the {@code DetailAST} to test.
+     * @param parentType the token type of {@code ast}'s parent.
+     * @param match the parent token type we're looking to match.
+     * @return {@code true} if {@code ast} makes up part of an
+     *         empty block contained under a {@code match} token type
      *         node.
      */
-    private boolean isEmptyBlock(DetailAST aAST, int aParentType, int aMatch)
-    {
-        final int type = aAST.getType();
+    private static boolean isEmptyBlock(DetailAST ast, int parentType, int match) {
+        final int type = ast.getType();
         if (type == TokenTypes.RCURLY) {
-            final DetailAST grandParent = aAST.getParent().getParent();
-            return (aParentType == TokenTypes.SLIST)
-                && (grandParent.getType() == aMatch);
+            final DetailAST grandParent = ast.getParent().getParent();
+            return parentType == TokenTypes.SLIST
+                && grandParent.getType() == match;
         }
 
-        return (type == TokenTypes.SLIST)
-            && (aParentType == aMatch)
-            && (aAST.getFirstChild().getType() == TokenTypes.RCURLY);
+        return type == TokenTypes.SLIST
+            && parentType == match
+            && ast.getFirstChild().getType() == TokenTypes.RCURLY;
+    }
+
+    /**
+     * Whether colon belongs to cases or defaults.
+     * @param currentType current
+     * @param parentType parent
+     * @return true if current token in colon of case or default tokens
+     */
+    private static boolean isColonOfCaseOrDefault(int currentType, int parentType) {
+        return currentType == TokenTypes.COLON
+                && (parentType == TokenTypes.LITERAL_DEFAULT
+                    || parentType == TokenTypes.LITERAL_CASE);
+    }
+
+    /**
+     * Whether colon belongs to for-each.
+     * @param currentType current
+     * @param parentType parent
+     * @return true if current token in colon of for-each token
+     */
+    private boolean isColonOfForEach(int currentType, int parentType) {
+        return currentType == TokenTypes.COLON
+            && parentType == TokenTypes.FOR_EACH_CLAUSE
+            && ignoreEnhancedForColon;
+    }
+
+    /**
+     * Is array initialization.
+     * @param currentType current token
+     * @param parentType parent token
+     * @return true is current token inside array initialization
+     */
+    private static boolean isArrayInitialization(int currentType, int parentType) {
+        return (currentType == TokenTypes.RCURLY
+                || currentType == TokenTypes.LCURLY)
+            && (parentType == TokenTypes.ARRAY_INIT
+                || parentType == TokenTypes.ANNOTATION_ARRAY_INIT);
+    }
+
+    /**
+     * Test if the given {@code DetailAST} is part of an allowed empty
+     * method block.
+     * @param ast the {@code DetailAST} to test.
+     * @param parentType the token type of {@code ast}'s parent.
+     * @return {@code true} if {@code ast} makes up part of an
+     *         allowed empty method block.
+     */
+    private boolean isEmptyMethodBlock(DetailAST ast, int parentType) {
+        return allowEmptyMethods
+            && isEmptyBlock(ast, parentType, TokenTypes.METHOD_DEF);
+    }
+
+    /**
+     * Test if the given {@code DetailAST} is part of an allowed empty
+     * constructor (ctor) block.
+     * @param ast the {@code DetailAST} to test.
+     * @param parentType the token type of {@code ast}'s parent.
+     * @return {@code true} if {@code ast} makes up part of an
+     *         allowed empty constructor block.
+     */
+    private boolean isEmptyCtorBlock(DetailAST ast, int parentType) {
+        return allowEmptyConstructors
+            && isEmptyBlock(ast, parentType, TokenTypes.CTOR_DEF);
+    }
+
+    /**
+     *
+     * @param ast ast the {@code DetailAST} to test.
+     * @param parentType the token type of {@code ast}'s parent.
+     * @return {@code true} if {@code ast} makes up part of an
+     *         allowed empty loop block.
+     */
+    private boolean isEmptyLoop(DetailAST ast, int parentType) {
+        return allowEmptyLoops
+            && (isEmptyBlock(ast, parentType, TokenTypes.LITERAL_FOR)
+                    || isEmptyBlock(ast,
+                            parentType, TokenTypes.LITERAL_WHILE)
+                            || isEmptyBlock(ast,
+                                    parentType, TokenTypes.LITERAL_DO));
+    }
+
+    /**
+     * Test if the given {@code DetailAST} is part of an empty block.
+     * An example empty block might look like the following
+     * <p>
+     * <pre>   class Foo {}</pre>
+     * </p>
+     *
+     * @param ast ast the {@code DetailAST} to test.
+     * @return {@code true} if {@code ast} makes up part of an
+     *         empty block contained under a {@code match} token type
+     *         node.
+     */
+    private static boolean isEmptyType(DetailAST ast) {
+        final int type = ast.getType();
+        final DetailAST nextSibling = ast.getNextSibling();
+        final DetailAST previousSibling = ast.getPreviousSibling();
+        return type == TokenTypes.LCURLY
+                && nextSibling.getType() == TokenTypes.RCURLY
+            || type == TokenTypes.RCURLY
+                && previousSibling != null
+                && previousSibling.getType() == TokenTypes.LCURLY;
     }
 }
