@@ -167,10 +167,10 @@ public class SuppressionCommentFilter
 
     /**
      * Set whether to look in C++ comments.
-     * @param checkCPP {@code true} if C++ comments are checked.
+     * @param checkCpp {@code true} if C++ comments are checked.
      */
-    public void setCheckCPP(boolean checkCPP) {
-        this.checkCPP = checkCPP;
+    public void setCheckCPP(boolean checkCpp) {
+        checkCPP = checkCpp;
     }
 
     /**
