@@ -433,7 +433,7 @@ public class MainTest {
     }
 
     @Test
-    public void testLoadPropertiesIOException() throws Exception {
+    public void testLoadPropertiesIoException() throws Exception {
         final Class<?>[] param = new Class<?>[1];
         param[0] = File.class;
         final Method method = Main.class.getDeclaredMethod("loadProperties", param);
@@ -508,7 +508,8 @@ public class MainTest {
         };
 
         exit.checkAssertionAfterwards(new Assertion() {
-            @Override public void checkAssertion() throws IOException {
+            @Override
+            public void checkAssertion() throws IOException {
                 final String expectedPath = getFilePath("checks/metrics") + File.separator;
                 final StringBuilder sb = new StringBuilder();
                 sb.append("Starting audit...").append(System.getProperty("line.separator"));
