@@ -29,8 +29,12 @@ import org.apache.commons.lang3.ArrayUtils;
 import org.junit.Assert;
 import org.junit.Test;
 
+import antlr.CommonHiddenStreamToken;
+
 import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.api.DetailAST;
+import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 
 public class RequireThisCheckTest extends BaseCheckTestSupport {
     @Override
@@ -49,6 +53,10 @@ public class RequireThisCheckTest extends BaseCheckTestSupport {
             "31:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
             "49:13: " + getCheckMessage(MSG_VARIABLE, "z", "\"this\""),
             "56:9: " + getCheckMessage(MSG_VARIABLE, "z", "\"this\""),
+            "113:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
+            "114:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
+            "115:9: " + getCheckMessage(MSG_METHOD, "instanceMethod", "\"this\""),
+            "121:13: " + getCheckMessage(MSG_METHOD, "instanceMethod", "\"this\""),
         };
         verify(checkConfig,
                getPath("InputRequireThis.java"),
@@ -62,6 +70,8 @@ public class RequireThisCheckTest extends BaseCheckTestSupport {
         checkConfig.addAttribute("checkFields", "false");
         final String[] expected = {
             "17:9: " + getCheckMessage(MSG_METHOD, "method1", "\"this\""),
+            "115:9: " + getCheckMessage(MSG_METHOD, "instanceMethod", "\"this\""),
+            "121:13: " + getCheckMessage(MSG_METHOD, "instanceMethod", "\"this\""),
         };
         verify(checkConfig,
                getPath("InputRequireThis.java"),
@@ -78,6 +88,8 @@ public class RequireThisCheckTest extends BaseCheckTestSupport {
             "31:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
             "49:13: " + getCheckMessage(MSG_VARIABLE, "z", "\"this\""),
             "56:9: " + getCheckMessage(MSG_VARIABLE, "z", "\"this\""),
+            "113:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
+            "114:9: " + getCheckMessage(MSG_VARIABLE, "i", "\"this\""),
         };
         verify(checkConfig,
                getPath("InputRequireThis.java"),
@@ -121,4 +133,12 @@ public class RequireThisCheckTest extends BaseCheckTestSupport {
                 getPath("InputRequireThis3.java"),
                 expected);
     }
+
+    @Test
+    public void testDefaultSwitch() {
+        final RequireThisCheck check = new RequireThisCheck();
+        final DetailAST ast = new DetailAST();
+        ast.initialize(new CommonHiddenStreamToken(TokenTypes.ENUM, "ENUM"));
+        check.visitToken(ast);
+    }
 }
